<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:template match="logfile">
    <html>
      <head>
        <title>
          <xsl:text>Logfile - </xsl:text>
          <xsl:apply-templates select="@app"/>
        </title>
        <style type="text/css">
          <![CDATA[
          body { font-family: Sans-Serif; background: #eeeef8; }
          h1 {color: #00A; letter-spacing: -1px;}
          .major { background: #ffffff; padding: 10px; margin: 5px 0 5px 0;}
          h2 { font-size: 14pt; margin: 8px; color: #00A;}
          .minor { background: #eeeef8; padding: 10px; margin: 5px 0 5px 0; border: dashed 1px #555; }
          h3 { font-size: 12pt; margin: 5px; color: #00A;}
          .internal { background: #ffffff; padding: 10px; margin: 5px 0 5px 0; font-size: 10pt;}
          h4 { font-size: 10pt; margin: 2px; color: #00A;}
          ul {padding-left: 10px; margin-left: 10px}
          pre {display: inline; margin-left: 2px; margin-right: 2px;}
          ]]>
        </style>
      </head>
      <body>
        <h1>Logfile - <xsl:apply-templates select="@app"/></h1>
        <xsl:for-each select="majorversion">
          <xsl:sort select="@id" order="descending"/>
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </body>
    </html>
  </xsl:template>
  <xsl:template match="majorversion">
    <div class="major">
      <xsl:attribute name="id">
        <xsl:value-of select="@id"/>
      </xsl:attribute>
      <h2>
        Version <xsl:value-of select="@id"/>
      </h2>
      <xsl:for-each select="minorversion">
        <xsl:sort select="@id" order="descending"/>
        <xsl:apply-templates select="."/>
      </xsl:for-each>
    </div>    
  </xsl:template>
  <xsl:template match="minorversion">
    <div class="minor">
      <xsl:attribute name="id">
        <xsl:value-of select="../@id"/>
        <xsl:text>.</xsl:text>
        <xsl:value-of select="@id"/>
      </xsl:attribute>
      <h3>Version <xsl:value-of select="../@id"/>.<xsl:value-of select="@id"/></h3>
      <xsl:for-each select="internal">
        <xsl:sort select="@id" data-type="number" order="descending"/>
        <xsl:apply-templates select="."/>
      </xsl:for-each>
    </div>
  </xsl:template>
  <xsl:template match="internal">
    <div class="internal">
      <xsl:attribute name="id">
        <xsl:value-of select="../../@id"/>
        <xsl:text>.</xsl:text>
        <xsl:value-of select="../@id"/>
        <xsl:text>.</xsl:text>
        <xsl:value-of select="@id"/>
      </xsl:attribute>
	  <h4>
		<xsl:text>Build </xsl:text>
		<xsl:value-of select="@id"/>
		<xsl:if test="@date">
          <br/>
		  <xsl:text> (</xsl:text>
		  <xsl:value-of select="@date"/>
		  <xsl:text>)</xsl:text>
		</xsl:if>
      </h4>
      <ul>
        <xsl:apply-templates/>
      </ul>
    </div>
  </xsl:template>
  <xsl:template match="item">
    <li>
      <xsl:choose>
        <xsl:when test="item">
          <xsl:apply-templates select="node()[name()!='item']"/>
          <ul>
            <xsl:apply-templates select="item"/>
          </ul>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates/>
        </xsl:otherwise>
      </xsl:choose>
    </li>
  </xsl:template>
  <xsl:template match="c">
    <pre>
      <xsl:apply-templates/>
    </pre>
  </xsl:template>
</xsl:stylesheet>